% ======================================================================
% simple model of traffic - time to work
%IN THIS VERSION READ AND MODIFY ALL THE AREAS WITH COMMENTS THAT START
%WITH %**
% Compares time to work for two routes and two sets of traffic conditions
%
% Model Parameter Definitions               Description
% Time to traverse block on local street	Distance / avg. speed
% Stop sign average stop time               30 second delay
% Time to traverse highway section          Distance / avg. speed
% Traffic light stopping time               Probability of green x avg. red
% Left turn on major road                   (Total cars turning/cars per green arrow) x light cycle
%
% ======================================================================
%** This version is a template from which you can run the scenarios for
%** different red light times.
%
%**Below red light probability is commented out.  Instead, we setup a
%**recurring loop that will run the model for a range of red light times and
%**ill in a matrix of the results.  Follow the comments below to make the
%**required changes in the code and analyze the results for your report.
%
% 
% =====================================================================% 

 city_block = 1000; % average city block length (feet)
 local_speed = 25;  % average speed for local streets (mph)
 major_speed = 35;  % average speed for a major street (mph)
 normal_freeway = 55; % average freeway speed in normal conditions (mph)
 congest_freeway = 20; % average freeway speed during congestion (mph)
 %red_prob = .01;     % Probability of red light at major intersection
 Avg_redlight = 2;   % average time for light to be red
 left_on_green = 6;  % number of cars per green arrow on left turn
 left_green_arrow = 4; %left turn light cycle time
 cars_left_peak = 12;  % number of cars turning left at peak hours
 cars_left_off_peak = 4; % off peak left turners
 
 %**First we need to insert statements set up empty matrices to hold the
 %**values of the normal, congested, and local street time to work estimates
 %**for each of the cases of red light probability we are asked to simulate.
 %**These are from 0.01 to 0.5 in .01 minute increments.  Use this to
 %**calculate how big the matrix needs to be.  Then fill in the statements
 %**below to create the three matrices.  The syntax you will use is like
 %**this:  MATRIXname = zeros(number_of_values,1).  So in the first example
 %**statement below, the matrix fnormal would create a matrix of zeros for 10
 %**rows and one column.  Fix this with the right number and add two more
 %**statements to account for the congestion and local times. Names need to
 %**match the names in the graphing statements on lines 131 - 133.
 fnormal = zeros(10,1);
 
 
 %**We also need a matrix of the same size to keep track of the values of red
 %**light probability so that we use those values on our final graph.
 %Create a statement where you call that matrix y and make it the same size as the
 %**others.
 
 
% Set up routes
% Store each leg of the route in a matrix - start with zeros
%**Now we change the program to add a recursive loop.  This loop starts with
%**the statement "for" and includes all statements until we hit the "end"
%**statement.  We want to do this for values of red_prob.  The first number
%**is the starting number, second one is the increment and the third one is
%**the limit.  So--- for red_prob = 0.05:0.05:1.0 -- would start at 0.05, add
%**0.05 for each iteration and continue until the value of red_prob gets to
%**1.0.  Fill in the correct numbers in the statement below.
for red_prob = 0.05:0.05:1.0
    %**Below we calculate a value x that will be a whole number to track our
    %**iterations.  The round function converts that number to an integer
    %**instead of a real number because we need an integer in the logic of
    %**the index statements used below and at the end of the loop.  y(x) will
    %**hold the red_prob where x will go from 1 to the upper limit of the
    %**iterations.  
    x = round(red_prob*100);
    y(x) = red_prob;
  freeway_normal = zeros(9,1);
  freeway_congest = zeros(9,1);
  local = zeros(10,1);

% Fill in freeway_normal
  freeway_normal(1)= ((2*city_block)/5280)/local_speed*60;
  freeway_normal(2)= 0.5;
  freeway_normal(3)= ((2*city_block)/5280)/local_speed*60;
  freeway_normal(4)= (2.5/normal_freeway)*60; %2.5 miles on freeway
  freeway_normal(5)= ((cars_left_peak/left_on_green)-1)*left_green_arrow; %left on major road
  freeway_normal(6)= ((1*city_block)/5280)/local_speed*60;
  freeway_normal(7)= red_prob*Avg_redlight;
  freeway_normal(8)=((2*city_block)/5280)/local_speed*60;
  freeway_normal(9)= 0;
  
% Fill in freeway_congested

  
  freeway_congest(1)= ((2*city_block)/5280)/local_speed*60;
  freeway_congest(2)= 0.5;
  freeway_congest(3)= ((2*city_block)/5280)/local_speed*60;
  freeway_congest(4)= (2.5/congest_freeway)*60; %2.5 miles on freeway
  freeway_congest(5)= ((cars_left_peak/left_on_green)-1)*left_green_arrow; %left on major road
  freeway_congest(6)= ((1*city_block)/5280)/local_speed*60;
  freeway_congest(7)= red_prob*Avg_redlight;
  freeway_congest(8)=((2*city_block)/5280)/local_speed*60;
  freeway_congest(9)= 0;  
  
% Fill in local route

  local(1) = ((2*city_block)/5280)/local_speed*60;
  local(2) = 0.5;
  local(3) = ((2*city_block)/5280)/local_speed*60;
  local(4) = (1.75/major_speed)*60; % 1.75 miles on major street
  local(5) = 5*red_prob*Avg_redlight; % 5 traffic lights
  local(6) = ((cars_left_peak/left_on_green)-1)*left_green_arrow; %left on major road
  local(7) = ((1*city_block)/5280)/local_speed*60;
  local(8) = red_prob*Avg_redlight;
  local(9) = ((2*city_block)/5280)/local_speed*60;

  %**Now we have to fill in the values in our matrix for each of the three
  %**routes.  The statement from our original program calculated the time for
  %**each route by summing the times of the individual parts of the trip.  We
  %**save this value in our matrix of final answers.  Using the value of x to
  %**mark what iteration we are in.  Fill in the appropriate statement for
  %**the other two variables below. Names must match those above and below.
  fnormal(x) = sum(freeway_normal);
  
end
%**This section graphs a line for each condition for all of the values
%**calculated for our model.  We will begin to learn about these graphing
%**statements in the next topic.  For now, you can just observe that we
%**plotting each value of our matrix against the value of red_prob
%**(represented as y) and assigning a different color to each.  A legend is
%**also created.
figure;hold('on');
set(gca, 'Box' , 'on');
h1 = plot(y,fnormal, 'r');
h2 = plot(y,fcongest, 'g');
h3 = plot(y,flocal, 'b');
legend([h1, h2, h3], {'Normal', 'Congest', 'Local'},'Location','NorthWest');  
% Now write the output to the screen
 % fprintf('\n Freeway_Reg   Freeway-Congest      Local ');
%fprintf('\n %8.2f %15.2f %15.2f', fnormal, fcongest, flocal);
%fprintf('\n')
% Use this section to fill in a matrix of answers related to the assignment
% and plot them out.
%First create 
  
  
